# Kupo Commands

> To close this help file, just press `j` or `k` to move to another file
> in the currently active directory.

## Moving around your filesystem

* `j` - go to next file in current directory
* `k` - go to previous file in current directory
* `h` - go to parent directory
* `l` - go to currently highlighted directory

## Moving around inside files

* `g` - go to top of file
* `G` - go to bottom of file

## Misc

* `d` - Toggle dark/light theme
* `?` - Open this help file